@@ -556,10 +556,11 @@ class ContactList(object):
 			defaultIndex = _index_number(numbers, selectedNumber)
 
 		for number, description in numbers:
+			prettyNumber = misc_utils.make_pretty(number)
 			if description:
-				label = "%s - %s" % (number, description)
+				label = "%s - %s" % (prettyNumber, description)
 			else:
-				label = number
+				label = prettyNumber
 			selector.addItem(label)
 		selector.setVisible(True)
 		if 1 < len(numbers):
@@ -585,7 +586,7 @@ class ContactList(object):
 			self._session.draft.set_selected_number(cid, number)
 
 	@misc_utils.log_exception(_moduleLogger)
-	def _on_remove_contact(self, index, toggled):
+	def _on_remove_contact(self, index, toggled = True):
 		with qui_utils.notify_error(self._app.errorLog):
 			self._session.draft.remove_contact(self._uiItems[index]["cid"])
 
@@ -1019,10 +1020,11 @@ class SMSEntryWindow(qwrappers.WindowWrapper):
 			defaultIndex = _index_number(numbers, selectedNumber)
 
 		for number, description in numbers:
+			prettyNumber = misc_utils.make_pretty(number)
 			if description:
-				label = "%s - %s" % (number, description)
+				label = "%s - %s" % (prettyNumber, description)
 			else:
-				label = number
+				label = prettyNumber
 			selector.addItem(label)
 		selector.setVisible(True)
 		if 1 < len(numbers):
